pari_seadata_small: PARI data package needed by ellap for large primes (small version)
======================================================================================

Description
-----------

PARI package "seadata_small": Needed by ellap for large primes. This
"small" one is a much smaller version that should be suitable for primes
up to 350 bits. These polynomials were extracted from the ECHIDNA
databases and computed by David R. Kohel.

License
-------

GPL version 2+


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/

